# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TestrunresultTestRunDetail(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'test_run_id': 'str',
        'name': 'str',
        'project_id': 'RimeUUID',
        'testing_type': 'RimeTestType',
        'model_task': 'RimeModelTask',
        'ref_data_id': 'str',
        'eval_data_id': 'str',
        'model_id': 'RimeUUID',
        'upload_time': 'datetime',
        'web_app_url': 'RimeSafeURL',
        'test_categories': 'list[TestrunTestCategoryType]',
        'metrics': 'TestrunresultTestRunMetrics',
        'status': 'RimeTestTaskStatus',
        'progress': 'str',
        'rime_version': 'str',
        'bin_time_interval': 'RimeTimeInterval',
        'ref_data_sampling_pct': 'float',
        'eval_data_sampling_pct': 'float',
        'schedule_id': 'RimeUUID'
    }

    attribute_map = {
        'test_run_id': 'testRunId',
        'name': 'name',
        'project_id': 'projectId',
        'testing_type': 'testingType',
        'model_task': 'modelTask',
        'ref_data_id': 'refDataId',
        'eval_data_id': 'evalDataId',
        'model_id': 'modelId',
        'upload_time': 'uploadTime',
        'web_app_url': 'webAppUrl',
        'test_categories': 'testCategories',
        'metrics': 'metrics',
        'status': 'status',
        'progress': 'progress',
        'rime_version': 'rimeVersion',
        'bin_time_interval': 'binTimeInterval',
        'ref_data_sampling_pct': 'refDataSamplingPct',
        'eval_data_sampling_pct': 'evalDataSamplingPct',
        'schedule_id': 'scheduleId'
    }

    def __init__(self, test_run_id=None, name=None, project_id=None, testing_type=None, model_task=None, ref_data_id=None, eval_data_id=None, model_id=None, upload_time=None, web_app_url=None, test_categories=None, metrics=None, status=None, progress=None, rime_version=None, bin_time_interval=None, ref_data_sampling_pct=None, eval_data_sampling_pct=None, schedule_id=None):  # noqa: E501
        """TestrunresultTestRunDetail - a model defined in Swagger"""  # noqa: E501
        self._test_run_id = None
        self._name = None
        self._project_id = None
        self._testing_type = None
        self._model_task = None
        self._ref_data_id = None
        self._eval_data_id = None
        self._model_id = None
        self._upload_time = None
        self._web_app_url = None
        self._test_categories = None
        self._metrics = None
        self._status = None
        self._progress = None
        self._rime_version = None
        self._bin_time_interval = None
        self._ref_data_sampling_pct = None
        self._eval_data_sampling_pct = None
        self._schedule_id = None
        self.discriminator = None
        if test_run_id is not None:
            self.test_run_id = test_run_id
        if name is not None:
            self.name = name
        if project_id is not None:
            self.project_id = project_id
        if testing_type is not None:
            self.testing_type = testing_type
        if model_task is not None:
            self.model_task = model_task
        if ref_data_id is not None:
            self.ref_data_id = ref_data_id
        if eval_data_id is not None:
            self.eval_data_id = eval_data_id
        if model_id is not None:
            self.model_id = model_id
        if upload_time is not None:
            self.upload_time = upload_time
        if web_app_url is not None:
            self.web_app_url = web_app_url
        if test_categories is not None:
            self.test_categories = test_categories
        if metrics is not None:
            self.metrics = metrics
        if status is not None:
            self.status = status
        if progress is not None:
            self.progress = progress
        if rime_version is not None:
            self.rime_version = rime_version
        if bin_time_interval is not None:
            self.bin_time_interval = bin_time_interval
        if ref_data_sampling_pct is not None:
            self.ref_data_sampling_pct = ref_data_sampling_pct
        if eval_data_sampling_pct is not None:
            self.eval_data_sampling_pct = eval_data_sampling_pct
        if schedule_id is not None:
            self.schedule_id = schedule_id

    @property
    def test_run_id(self):
        """Gets the test_run_id of this TestrunresultTestRunDetail.  # noqa: E501

        Uniquely specifies a Test Run.  # noqa: E501

        :return: The test_run_id of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: str
        """
        return self._test_run_id

    @test_run_id.setter
    def test_run_id(self, test_run_id):
        """Sets the test_run_id of this TestrunresultTestRunDetail.

        Uniquely specifies a Test Run.  # noqa: E501

        :param test_run_id: The test_run_id of this TestrunresultTestRunDetail.  # noqa: E501
        :type: str
        """

        self._test_run_id = test_run_id

    @property
    def name(self):
        """Gets the name of this TestrunresultTestRunDetail.  # noqa: E501

        The name of the Test Run.  # noqa: E501

        :return: The name of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TestrunresultTestRunDetail.

        The name of the Test Run.  # noqa: E501

        :param name: The name of this TestrunresultTestRunDetail.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def project_id(self):
        """Gets the project_id of this TestrunresultTestRunDetail.  # noqa: E501


        :return: The project_id of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this TestrunresultTestRunDetail.


        :param project_id: The project_id of this TestrunresultTestRunDetail.  # noqa: E501
        :type: RimeUUID
        """

        self._project_id = project_id

    @property
    def testing_type(self):
        """Gets the testing_type of this TestrunresultTestRunDetail.  # noqa: E501


        :return: The testing_type of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: RimeTestType
        """
        return self._testing_type

    @testing_type.setter
    def testing_type(self, testing_type):
        """Sets the testing_type of this TestrunresultTestRunDetail.


        :param testing_type: The testing_type of this TestrunresultTestRunDetail.  # noqa: E501
        :type: RimeTestType
        """

        self._testing_type = testing_type

    @property
    def model_task(self):
        """Gets the model_task of this TestrunresultTestRunDetail.  # noqa: E501


        :return: The model_task of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: RimeModelTask
        """
        return self._model_task

    @model_task.setter
    def model_task(self, model_task):
        """Sets the model_task of this TestrunresultTestRunDetail.


        :param model_task: The model_task of this TestrunresultTestRunDetail.  # noqa: E501
        :type: RimeModelTask
        """

        self._model_task = model_task

    @property
    def ref_data_id(self):
        """Gets the ref_data_id of this TestrunresultTestRunDetail.  # noqa: E501

        Uniquely specifies a reference dataset.  # noqa: E501

        :return: The ref_data_id of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: str
        """
        return self._ref_data_id

    @ref_data_id.setter
    def ref_data_id(self, ref_data_id):
        """Sets the ref_data_id of this TestrunresultTestRunDetail.

        Uniquely specifies a reference dataset.  # noqa: E501

        :param ref_data_id: The ref_data_id of this TestrunresultTestRunDetail.  # noqa: E501
        :type: str
        """

        self._ref_data_id = ref_data_id

    @property
    def eval_data_id(self):
        """Gets the eval_data_id of this TestrunresultTestRunDetail.  # noqa: E501

        Uniquely specifies an evaluation dataset.  # noqa: E501

        :return: The eval_data_id of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: str
        """
        return self._eval_data_id

    @eval_data_id.setter
    def eval_data_id(self, eval_data_id):
        """Sets the eval_data_id of this TestrunresultTestRunDetail.

        Uniquely specifies an evaluation dataset.  # noqa: E501

        :param eval_data_id: The eval_data_id of this TestrunresultTestRunDetail.  # noqa: E501
        :type: str
        """

        self._eval_data_id = eval_data_id

    @property
    def model_id(self):
        """Gets the model_id of this TestrunresultTestRunDetail.  # noqa: E501


        :return: The model_id of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this TestrunresultTestRunDetail.


        :param model_id: The model_id of this TestrunresultTestRunDetail.  # noqa: E501
        :type: RimeUUID
        """

        self._model_id = model_id

    @property
    def upload_time(self):
        """Gets the upload_time of this TestrunresultTestRunDetail.  # noqa: E501

        The upload time of the test run.  # noqa: E501

        :return: The upload_time of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: datetime
        """
        return self._upload_time

    @upload_time.setter
    def upload_time(self, upload_time):
        """Sets the upload_time of this TestrunresultTestRunDetail.

        The upload time of the test run.  # noqa: E501

        :param upload_time: The upload_time of this TestrunresultTestRunDetail.  # noqa: E501
        :type: datetime
        """

        self._upload_time = upload_time

    @property
    def web_app_url(self):
        """Gets the web_app_url of this TestrunresultTestRunDetail.  # noqa: E501


        :return: The web_app_url of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: RimeSafeURL
        """
        return self._web_app_url

    @web_app_url.setter
    def web_app_url(self, web_app_url):
        """Sets the web_app_url of this TestrunresultTestRunDetail.


        :param web_app_url: The web_app_url of this TestrunresultTestRunDetail.  # noqa: E501
        :type: RimeSafeURL
        """

        self._web_app_url = web_app_url

    @property
    def test_categories(self):
        """Gets the test_categories of this TestrunresultTestRunDetail.  # noqa: E501

        The list of child references to the category tests belonging to this test run.  # noqa: E501

        :return: The test_categories of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: list[TestrunTestCategoryType]
        """
        return self._test_categories

    @test_categories.setter
    def test_categories(self, test_categories):
        """Sets the test_categories of this TestrunresultTestRunDetail.

        The list of child references to the category tests belonging to this test run.  # noqa: E501

        :param test_categories: The test_categories of this TestrunresultTestRunDetail.  # noqa: E501
        :type: list[TestrunTestCategoryType]
        """

        self._test_categories = test_categories

    @property
    def metrics(self):
        """Gets the metrics of this TestrunresultTestRunDetail.  # noqa: E501


        :return: The metrics of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: TestrunresultTestRunMetrics
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """Sets the metrics of this TestrunresultTestRunDetail.


        :param metrics: The metrics of this TestrunresultTestRunDetail.  # noqa: E501
        :type: TestrunresultTestRunMetrics
        """

        self._metrics = metrics

    @property
    def status(self):
        """Gets the status of this TestrunresultTestRunDetail.  # noqa: E501


        :return: The status of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: RimeTestTaskStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this TestrunresultTestRunDetail.


        :param status: The status of this TestrunresultTestRunDetail.  # noqa: E501
        :type: RimeTestTaskStatus
        """

        self._status = status

    @property
    def progress(self):
        """Gets the progress of this TestrunresultTestRunDetail.  # noqa: E501

        Human-readable succinct message about the progress of the test run.  # noqa: E501

        :return: The progress of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: str
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this TestrunresultTestRunDetail.

        Human-readable succinct message about the progress of the test run.  # noqa: E501

        :param progress: The progress of this TestrunresultTestRunDetail.  # noqa: E501
        :type: str
        """

        self._progress = progress

    @property
    def rime_version(self):
        """Gets the rime_version of this TestrunresultTestRunDetail.  # noqa: E501

        The version of Robust Intelligence that ran this test.  # noqa: E501

        :return: The rime_version of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: str
        """
        return self._rime_version

    @rime_version.setter
    def rime_version(self, rime_version):
        """Sets the rime_version of this TestrunresultTestRunDetail.

        The version of Robust Intelligence that ran this test.  # noqa: E501

        :param rime_version: The rime_version of this TestrunresultTestRunDetail.  # noqa: E501
        :type: str
        """

        self._rime_version = rime_version

    @property
    def bin_time_interval(self):
        """Gets the bin_time_interval of this TestrunresultTestRunDetail.  # noqa: E501


        :return: The bin_time_interval of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: RimeTimeInterval
        """
        return self._bin_time_interval

    @bin_time_interval.setter
    def bin_time_interval(self, bin_time_interval):
        """Sets the bin_time_interval of this TestrunresultTestRunDetail.


        :param bin_time_interval: The bin_time_interval of this TestrunresultTestRunDetail.  # noqa: E501
        :type: RimeTimeInterval
        """

        self._bin_time_interval = bin_time_interval

    @property
    def ref_data_sampling_pct(self):
        """Gets the ref_data_sampling_pct of this TestrunresultTestRunDetail.  # noqa: E501

        Percentage of the reference dataset used for this test. If no sampling occurred, this will be 1.0.  # noqa: E501

        :return: The ref_data_sampling_pct of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: float
        """
        return self._ref_data_sampling_pct

    @ref_data_sampling_pct.setter
    def ref_data_sampling_pct(self, ref_data_sampling_pct):
        """Sets the ref_data_sampling_pct of this TestrunresultTestRunDetail.

        Percentage of the reference dataset used for this test. If no sampling occurred, this will be 1.0.  # noqa: E501

        :param ref_data_sampling_pct: The ref_data_sampling_pct of this TestrunresultTestRunDetail.  # noqa: E501
        :type: float
        """

        self._ref_data_sampling_pct = ref_data_sampling_pct

    @property
    def eval_data_sampling_pct(self):
        """Gets the eval_data_sampling_pct of this TestrunresultTestRunDetail.  # noqa: E501

        Percentage of the evaluation dataset used for this test. If no sampling occurred, this will be 1.0.  # noqa: E501

        :return: The eval_data_sampling_pct of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: float
        """
        return self._eval_data_sampling_pct

    @eval_data_sampling_pct.setter
    def eval_data_sampling_pct(self, eval_data_sampling_pct):
        """Sets the eval_data_sampling_pct of this TestrunresultTestRunDetail.

        Percentage of the evaluation dataset used for this test. If no sampling occurred, this will be 1.0.  # noqa: E501

        :param eval_data_sampling_pct: The eval_data_sampling_pct of this TestrunresultTestRunDetail.  # noqa: E501
        :type: float
        """

        self._eval_data_sampling_pct = eval_data_sampling_pct

    @property
    def schedule_id(self):
        """Gets the schedule_id of this TestrunresultTestRunDetail.  # noqa: E501


        :return: The schedule_id of this TestrunresultTestRunDetail.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._schedule_id

    @schedule_id.setter
    def schedule_id(self, schedule_id):
        """Sets the schedule_id of this TestrunresultTestRunDetail.


        :param schedule_id: The schedule_id of this TestrunresultTestRunDetail.  # noqa: E501
        :type: RimeUUID
        """

        self._schedule_id = schedule_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TestrunresultTestRunDetail, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TestrunresultTestRunDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DetectionSecurityEventDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'SecurityEventDetailsSecurityEventType',
        'effect_on_model': 'list[str]',
        'possible_intent': 'list[str]',
        'evidence': 'list[str]',
        'recommendations': 'list[str]',
        'datapoints': 'list[SecurityEventDetailsFlaggedDatapoint]'
    }

    attribute_map = {
        'type': 'type',
        'effect_on_model': 'effectOnModel',
        'possible_intent': 'possibleIntent',
        'evidence': 'evidence',
        'recommendations': 'recommendations',
        'datapoints': 'datapoints'
    }

    def __init__(self, type=None, effect_on_model=None, possible_intent=None, evidence=None, recommendations=None, datapoints=None):  # noqa: E501
        """DetectionSecurityEventDetails - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._effect_on_model = None
        self._possible_intent = None
        self._evidence = None
        self._recommendations = None
        self._datapoints = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if effect_on_model is not None:
            self.effect_on_model = effect_on_model
        if possible_intent is not None:
            self.possible_intent = possible_intent
        if evidence is not None:
            self.evidence = evidence
        if recommendations is not None:
            self.recommendations = recommendations
        if datapoints is not None:
            self.datapoints = datapoints

    @property
    def type(self):
        """Gets the type of this DetectionSecurityEventDetails.  # noqa: E501


        :return: The type of this DetectionSecurityEventDetails.  # noqa: E501
        :rtype: SecurityEventDetailsSecurityEventType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DetectionSecurityEventDetails.


        :param type: The type of this DetectionSecurityEventDetails.  # noqa: E501
        :type: SecurityEventDetailsSecurityEventType
        """

        self._type = type

    @property
    def effect_on_model(self):
        """Gets the effect_on_model of this DetectionSecurityEventDetails.  # noqa: E501


        :return: The effect_on_model of this DetectionSecurityEventDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._effect_on_model

    @effect_on_model.setter
    def effect_on_model(self, effect_on_model):
        """Sets the effect_on_model of this DetectionSecurityEventDetails.


        :param effect_on_model: The effect_on_model of this DetectionSecurityEventDetails.  # noqa: E501
        :type: list[str]
        """

        self._effect_on_model = effect_on_model

    @property
    def possible_intent(self):
        """Gets the possible_intent of this DetectionSecurityEventDetails.  # noqa: E501


        :return: The possible_intent of this DetectionSecurityEventDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._possible_intent

    @possible_intent.setter
    def possible_intent(self, possible_intent):
        """Sets the possible_intent of this DetectionSecurityEventDetails.


        :param possible_intent: The possible_intent of this DetectionSecurityEventDetails.  # noqa: E501
        :type: list[str]
        """

        self._possible_intent = possible_intent

    @property
    def evidence(self):
        """Gets the evidence of this DetectionSecurityEventDetails.  # noqa: E501


        :return: The evidence of this DetectionSecurityEventDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._evidence

    @evidence.setter
    def evidence(self, evidence):
        """Sets the evidence of this DetectionSecurityEventDetails.


        :param evidence: The evidence of this DetectionSecurityEventDetails.  # noqa: E501
        :type: list[str]
        """

        self._evidence = evidence

    @property
    def recommendations(self):
        """Gets the recommendations of this DetectionSecurityEventDetails.  # noqa: E501


        :return: The recommendations of this DetectionSecurityEventDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._recommendations

    @recommendations.setter
    def recommendations(self, recommendations):
        """Sets the recommendations of this DetectionSecurityEventDetails.


        :param recommendations: The recommendations of this DetectionSecurityEventDetails.  # noqa: E501
        :type: list[str]
        """

        self._recommendations = recommendations

    @property
    def datapoints(self):
        """Gets the datapoints of this DetectionSecurityEventDetails.  # noqa: E501

        Include descriptions of all the flagged datapoints for the attack.  # noqa: E501

        :return: The datapoints of this DetectionSecurityEventDetails.  # noqa: E501
        :rtype: list[SecurityEventDetailsFlaggedDatapoint]
        """
        return self._datapoints

    @datapoints.setter
    def datapoints(self, datapoints):
        """Sets the datapoints of this DetectionSecurityEventDetails.

        Include descriptions of all the flagged datapoints for the attack.  # noqa: E501

        :param datapoints: The datapoints of this DetectionSecurityEventDetails.  # noqa: E501
        :type: list[SecurityEventDetailsFlaggedDatapoint]
        """

        self._datapoints = datapoints

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DetectionSecurityEventDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DetectionSecurityEventDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FilescanningPackageURL(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'SchemafilescanningPackageType',
        'namespace': 'str',
        'name': 'str',
        'version': 'str',
        'qualifiers': 'dict(str, str)',
        'subpath': 'str'
    }

    attribute_map = {
        'type': 'type',
        'namespace': 'namespace',
        'name': 'name',
        'version': 'version',
        'qualifiers': 'qualifiers',
        'subpath': 'subpath'
    }

    def __init__(self, type=None, namespace=None, name=None, version=None, qualifiers=None, subpath=None):  # noqa: E501
        """FilescanningPackageURL - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._namespace = None
        self._name = None
        self._version = None
        self._qualifiers = None
        self._subpath = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if namespace is not None:
            self.namespace = namespace
        if name is not None:
            self.name = name
        if version is not None:
            self.version = version
        if qualifiers is not None:
            self.qualifiers = qualifiers
        if subpath is not None:
            self.subpath = subpath

    @property
    def type(self):
        """Gets the type of this FilescanningPackageURL.  # noqa: E501


        :return: The type of this FilescanningPackageURL.  # noqa: E501
        :rtype: SchemafilescanningPackageType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this FilescanningPackageURL.


        :param type: The type of this FilescanningPackageURL.  # noqa: E501
        :type: SchemafilescanningPackageType
        """

        self._type = type

    @property
    def namespace(self):
        """Gets the namespace of this FilescanningPackageURL.  # noqa: E501

        Optional. The name prefix such as a GitHub user or organization, Maven groupid, or a Docker image owner.  # noqa: E501

        :return: The namespace of this FilescanningPackageURL.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this FilescanningPackageURL.

        Optional. The name prefix such as a GitHub user or organization, Maven groupid, or a Docker image owner.  # noqa: E501

        :param namespace: The namespace of this FilescanningPackageURL.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    @property
    def name(self):
        """Gets the name of this FilescanningPackageURL.  # noqa: E501

        The name of the package.  # noqa: E501

        :return: The name of this FilescanningPackageURL.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FilescanningPackageURL.

        The name of the package.  # noqa: E501

        :param name: The name of this FilescanningPackageURL.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def version(self):
        """Gets the version of this FilescanningPackageURL.  # noqa: E501

        Optional. The version of the package.  # noqa: E501

        :return: The version of this FilescanningPackageURL.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this FilescanningPackageURL.

        Optional. The version of the package.  # noqa: E501

        :param version: The version of this FilescanningPackageURL.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def qualifiers(self):
        """Gets the qualifiers of this FilescanningPackageURL.  # noqa: E501

        Optional. Additional qualifying data for a package such as an OS, architecture, a distro, etc.  # noqa: E501

        :return: The qualifiers of this FilescanningPackageURL.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._qualifiers

    @qualifiers.setter
    def qualifiers(self, qualifiers):
        """Sets the qualifiers of this FilescanningPackageURL.

        Optional. Additional qualifying data for a package such as an OS, architecture, a distro, etc.  # noqa: E501

        :param qualifiers: The qualifiers of this FilescanningPackageURL.  # noqa: E501
        :type: dict(str, str)
        """

        self._qualifiers = qualifiers

    @property
    def subpath(self):
        """Gets the subpath of this FilescanningPackageURL.  # noqa: E501

        Optional. A subpath within a package, relative to the package root.  # noqa: E501

        :return: The subpath of this FilescanningPackageURL.  # noqa: E501
        :rtype: str
        """
        return self._subpath

    @subpath.setter
    def subpath(self, subpath):
        """Sets the subpath of this FilescanningPackageURL.

        Optional. A subpath within a package, relative to the package root.  # noqa: E501

        :param subpath: The subpath of this FilescanningPackageURL.  # noqa: E501
        :type: str
        """

        self._subpath = subpath

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FilescanningPackageURL, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FilescanningPackageURL):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class RegistryServiceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def registry_service_delete_dataset(self, dataset_id, **kwargs):  # noqa: E501
        """DeleteDataset  # noqa: E501

        Delete a Dataset from the Registry.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_delete_dataset(dataset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset_id: Uniquely specifies a Dataset. (required)
        :return: RimeDeleteDatasetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registry_service_delete_dataset_with_http_info(dataset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.registry_service_delete_dataset_with_http_info(dataset_id, **kwargs)  # noqa: E501
            return data

    def registry_service_delete_dataset_with_http_info(self, dataset_id, **kwargs):  # noqa: E501
        """DeleteDataset  # noqa: E501

        Delete a Dataset from the Registry.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_delete_dataset_with_http_info(dataset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset_id: Uniquely specifies a Dataset. (required)
        :return: RimeDeleteDatasetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dataset_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registry_service_delete_dataset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'dataset_id' is set
        if ('dataset_id' not in params or
                params['dataset_id'] is None):
            raise ValueError("Missing the required parameter `dataset_id` when calling `registry_service_delete_dataset`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'dataset_id' in params:
            path_params['datasetId'] = params['dataset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/registry/dataset/{datasetId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeDeleteDatasetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def registry_service_delete_model(self, model_id_uuid, **kwargs):  # noqa: E501
        """DeleteModel  # noqa: E501

        Delete a Model from the Registry.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_delete_model(model_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id_uuid: Unique object ID. (required)
        :return: RimeDeleteModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registry_service_delete_model_with_http_info(model_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.registry_service_delete_model_with_http_info(model_id_uuid, **kwargs)  # noqa: E501
            return data

    def registry_service_delete_model_with_http_info(self, model_id_uuid, **kwargs):  # noqa: E501
        """DeleteModel  # noqa: E501

        Delete a Model from the Registry.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_delete_model_with_http_info(model_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id_uuid: Unique object ID. (required)
        :return: RimeDeleteModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registry_service_delete_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id_uuid' is set
        if ('model_id_uuid' not in params or
                params['model_id_uuid'] is None):
            raise ValueError("Missing the required parameter `model_id_uuid` when calling `registry_service_delete_model`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id_uuid' in params:
            path_params['modelId.uuid'] = params['model_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/registry/model/{modelId.uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeDeleteModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def registry_service_delete_prediction_set(self, model_id_uuid, dataset_id, **kwargs):  # noqa: E501
        """DeletePredictionSet  # noqa: E501

        Delete the Prediction set corresponding to a specified Model and Dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_delete_prediction_set(model_id_uuid, dataset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id_uuid: Unique object ID. (required)
        :param str dataset_id: Uniquely specifies a Dataset. (required)
        :return: RimeDeletePredictionSetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registry_service_delete_prediction_set_with_http_info(model_id_uuid, dataset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.registry_service_delete_prediction_set_with_http_info(model_id_uuid, dataset_id, **kwargs)  # noqa: E501
            return data

    def registry_service_delete_prediction_set_with_http_info(self, model_id_uuid, dataset_id, **kwargs):  # noqa: E501
        """DeletePredictionSet  # noqa: E501

        Delete the Prediction set corresponding to a specified Model and Dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_delete_prediction_set_with_http_info(model_id_uuid, dataset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id_uuid: Unique object ID. (required)
        :param str dataset_id: Uniquely specifies a Dataset. (required)
        :return: RimeDeletePredictionSetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id_uuid', 'dataset_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registry_service_delete_prediction_set" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id_uuid' is set
        if ('model_id_uuid' not in params or
                params['model_id_uuid'] is None):
            raise ValueError("Missing the required parameter `model_id_uuid` when calling `registry_service_delete_prediction_set`")  # noqa: E501
        # verify the required parameter 'dataset_id' is set
        if ('dataset_id' not in params or
                params['dataset_id'] is None):
            raise ValueError("Missing the required parameter `dataset_id` when calling `registry_service_delete_prediction_set`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id_uuid' in params:
            path_params['modelId.uuid'] = params['model_id_uuid']  # noqa: E501
        if 'dataset_id' in params:
            path_params['datasetId'] = params['dataset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/registry/prediction/{modelId.uuid}/{datasetId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeDeletePredictionSetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def registry_service_get_dataset(self, **kwargs):  # noqa: E501
        """GetDataset  # noqa: E501

        Returns information about a registered Dataset. Allows for searching by ID or name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_get_dataset(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset_id: Uniquely specifies a Dataset.
        :param str dataset_name: Unique name of a Dataset.
        :return: RimeGetDatasetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registry_service_get_dataset_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.registry_service_get_dataset_with_http_info(**kwargs)  # noqa: E501
            return data

    def registry_service_get_dataset_with_http_info(self, **kwargs):  # noqa: E501
        """GetDataset  # noqa: E501

        Returns information about a registered Dataset. Allows for searching by ID or name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_get_dataset_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset_id: Uniquely specifies a Dataset.
        :param str dataset_name: Unique name of a Dataset.
        :return: RimeGetDatasetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dataset_id', 'dataset_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registry_service_get_dataset" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'dataset_id' in params:
            query_params.append(('datasetId', params['dataset_id']))  # noqa: E501
        if 'dataset_name' in params:
            query_params.append(('datasetName', params['dataset_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/registry/dataset', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetDatasetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def registry_service_get_model(self, **kwargs):  # noqa: E501
        """GetModel  # noqa: E501

        Returns information about a registered Model. Allows for searching by ID or name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_get_model(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id_uuid: Unique object ID.
        :param str model_name: Unique name of a Model.
        :return: RimeGetModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registry_service_get_model_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.registry_service_get_model_with_http_info(**kwargs)  # noqa: E501
            return data

    def registry_service_get_model_with_http_info(self, **kwargs):  # noqa: E501
        """GetModel  # noqa: E501

        Returns information about a registered Model. Allows for searching by ID or name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_get_model_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id_uuid: Unique object ID.
        :param str model_name: Unique name of a Model.
        :return: RimeGetModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id_uuid', 'model_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registry_service_get_model" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'model_id_uuid' in params:
            query_params.append(('modelId.uuid', params['model_id_uuid']))  # noqa: E501
        if 'model_name' in params:
            query_params.append(('modelName', params['model_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/registry/model', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def registry_service_get_prediction_set(self, model_id_uuid, dataset_id, **kwargs):  # noqa: E501
        """GetPredictionSet  # noqa: E501

        Returns information about a registered Prediction set.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_get_prediction_set(model_id_uuid, dataset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id_uuid: Unique object ID. (required)
        :param str dataset_id: Uniquely specifies a Dataset. (required)
        :return: RimeGetPredictionSetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registry_service_get_prediction_set_with_http_info(model_id_uuid, dataset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.registry_service_get_prediction_set_with_http_info(model_id_uuid, dataset_id, **kwargs)  # noqa: E501
            return data

    def registry_service_get_prediction_set_with_http_info(self, model_id_uuid, dataset_id, **kwargs):  # noqa: E501
        """GetPredictionSet  # noqa: E501

        Returns information about a registered Prediction set.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_get_prediction_set_with_http_info(model_id_uuid, dataset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id_uuid: Unique object ID. (required)
        :param str dataset_id: Uniquely specifies a Dataset. (required)
        :return: RimeGetPredictionSetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id_uuid', 'dataset_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registry_service_get_prediction_set" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id_uuid' is set
        if ('model_id_uuid' not in params or
                params['model_id_uuid'] is None):
            raise ValueError("Missing the required parameter `model_id_uuid` when calling `registry_service_get_prediction_set`")  # noqa: E501
        # verify the required parameter 'dataset_id' is set
        if ('dataset_id' not in params or
                params['dataset_id'] is None):
            raise ValueError("Missing the required parameter `dataset_id` when calling `registry_service_get_prediction_set`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id_uuid' in params:
            path_params['modelId.uuid'] = params['model_id_uuid']  # noqa: E501
        if 'dataset_id' in params:
            path_params['datasetId'] = params['dataset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/registry/prediction/{modelId.uuid}/{datasetId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetPredictionSetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def registry_service_list_datasets(self, project_id_uuid, **kwargs):  # noqa: E501
        """ListDatasets  # noqa: E501

        List all Datasets in the Registry with optional filters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_list_datasets(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :param datetime first_page_req_scheduled_ct_intervals_start_time:
        :param datetime first_page_req_scheduled_ct_intervals_end_time:
        :param str page_token: Specifies a page of the list returned by a ListDatasets query. The ListDatasets query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageReq field.
        :param str page_size: The maximum number of Dataset objects to return in a single page.
        :return: RimeListDatasetsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registry_service_list_datasets_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.registry_service_list_datasets_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
            return data

    def registry_service_list_datasets_with_http_info(self, project_id_uuid, **kwargs):  # noqa: E501
        """ListDatasets  # noqa: E501

        List all Datasets in the Registry with optional filters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_list_datasets_with_http_info(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :param datetime first_page_req_scheduled_ct_intervals_start_time:
        :param datetime first_page_req_scheduled_ct_intervals_end_time:
        :param str page_token: Specifies a page of the list returned by a ListDatasets query. The ListDatasets query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageReq field.
        :param str page_size: The maximum number of Dataset objects to return in a single page.
        :return: RimeListDatasetsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id_uuid', 'first_page_req_scheduled_ct_intervals_start_time', 'first_page_req_scheduled_ct_intervals_end_time', 'page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registry_service_list_datasets" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `registry_service_list_datasets`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501

        query_params = []
        if 'first_page_req_scheduled_ct_intervals_start_time' in params:
            query_params.append(('firstPageReq.scheduledCtIntervals.startTime', params['first_page_req_scheduled_ct_intervals_start_time']))  # noqa: E501
        if 'first_page_req_scheduled_ct_intervals_end_time' in params:
            query_params.append(('firstPageReq.scheduledCtIntervals.endTime', params['first_page_req_scheduled_ct_intervals_end_time']))  # noqa: E501
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/registry/{projectId.uuid}/dataset', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListDatasetsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def registry_service_list_models(self, project_id_uuid, **kwargs):  # noqa: E501
        """ListModels  # noqa: E501

        List all Models in the Registry of the specified Project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_list_models(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :param str page_token: Specifies a page of the list returned by a ListModels query. The ListModels query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageReq field.
        :param str page_size: The maximum number of Model objects to return in a single page.
        :return: RimeListModelsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registry_service_list_models_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.registry_service_list_models_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
            return data

    def registry_service_list_models_with_http_info(self, project_id_uuid, **kwargs):  # noqa: E501
        """ListModels  # noqa: E501

        List all Models in the Registry of the specified Project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_list_models_with_http_info(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :param str page_token: Specifies a page of the list returned by a ListModels query. The ListModels query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageReq field.
        :param str page_size: The maximum number of Model objects to return in a single page.
        :return: RimeListModelsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id_uuid', 'page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registry_service_list_models" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `registry_service_list_models`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501

        query_params = []
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/registry/{projectId.uuid}/model', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListModelsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def registry_service_list_prediction_sets(self, project_id_uuid, **kwargs):  # noqa: E501
        """ListPredictionSets  # noqa: E501

        List all Prediction sets in the Registry with optional filters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_list_prediction_sets(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :param str first_page_req_model_id: Uniquely specifies a Model.
        :param str first_page_req_dataset_id: Uniquely specifies a Dataset.
        :param str page_token: Specifies a page of the list returned by a ListPredictions query. The ListPredictions query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageReq field.
        :param str page_size: The maximum number of Prediction objects to return in a single page.
        :return: RimeListPredictionSetsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registry_service_list_prediction_sets_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.registry_service_list_prediction_sets_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
            return data

    def registry_service_list_prediction_sets_with_http_info(self, project_id_uuid, **kwargs):  # noqa: E501
        """ListPredictionSets  # noqa: E501

        List all Prediction sets in the Registry with optional filters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_list_prediction_sets_with_http_info(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :param str first_page_req_model_id: Uniquely specifies a Model.
        :param str first_page_req_dataset_id: Uniquely specifies a Dataset.
        :param str page_token: Specifies a page of the list returned by a ListPredictions query. The ListPredictions query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageReq field.
        :param str page_size: The maximum number of Prediction objects to return in a single page.
        :return: RimeListPredictionSetsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id_uuid', 'first_page_req_model_id', 'first_page_req_dataset_id', 'page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registry_service_list_prediction_sets" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `registry_service_list_prediction_sets`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501

        query_params = []
        if 'first_page_req_model_id' in params:
            query_params.append(('firstPageReq.modelId', params['first_page_req_model_id']))  # noqa: E501
        if 'first_page_req_dataset_id' in params:
            query_params.append(('firstPageReq.datasetId', params['first_page_req_dataset_id']))  # noqa: E501
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/registry/{projectId.uuid}/prediction', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListPredictionSetsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def registry_service_register_dataset(self, body, project_id_uuid, **kwargs):  # noqa: E501
        """RegisterDataset  # noqa: E501

        Register a new Dataset for the specified Project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_register_dataset(body, project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectIdUuidDatasetBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :return: RimeRegisterDatasetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registry_service_register_dataset_with_http_info(body, project_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.registry_service_register_dataset_with_http_info(body, project_id_uuid, **kwargs)  # noqa: E501
            return data

    def registry_service_register_dataset_with_http_info(self, body, project_id_uuid, **kwargs):  # noqa: E501
        """RegisterDataset  # noqa: E501

        Register a new Dataset for the specified Project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_register_dataset_with_http_info(body, project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectIdUuidDatasetBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :return: RimeRegisterDatasetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registry_service_register_dataset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `registry_service_register_dataset`")  # noqa: E501
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `registry_service_register_dataset`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/registry/{projectId.uuid}/dataset', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeRegisterDatasetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def registry_service_register_model(self, body, project_id_uuid, **kwargs):  # noqa: E501
        """RegisterModel  # noqa: E501

        Register a new Model for the specified Project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_register_model(body, project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectIdUuidModelBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :return: RimeRegisterModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registry_service_register_model_with_http_info(body, project_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.registry_service_register_model_with_http_info(body, project_id_uuid, **kwargs)  # noqa: E501
            return data

    def registry_service_register_model_with_http_info(self, body, project_id_uuid, **kwargs):  # noqa: E501
        """RegisterModel  # noqa: E501

        Register a new Model for the specified Project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_register_model_with_http_info(body, project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectIdUuidModelBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :return: RimeRegisterModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registry_service_register_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `registry_service_register_model`")  # noqa: E501
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `registry_service_register_model`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/registry/{projectId.uuid}/model', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeRegisterModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def registry_service_register_prediction_set(self, body, project_id_uuid, model_id_uuid, dataset_id, **kwargs):  # noqa: E501
        """RegisterPredictionSet  # noqa: E501

        Register a Prediction set corresponding to a specified Model and Dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_register_prediction_set(body, project_id_uuid, model_id_uuid, dataset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DatasetIdPredictionBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :param str model_id_uuid: Unique object ID. (required)
        :param str dataset_id: Uniquely specifies a Dataset. (required)
        :return: RimeRegisterPredictionSetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registry_service_register_prediction_set_with_http_info(body, project_id_uuid, model_id_uuid, dataset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.registry_service_register_prediction_set_with_http_info(body, project_id_uuid, model_id_uuid, dataset_id, **kwargs)  # noqa: E501
            return data

    def registry_service_register_prediction_set_with_http_info(self, body, project_id_uuid, model_id_uuid, dataset_id, **kwargs):  # noqa: E501
        """RegisterPredictionSet  # noqa: E501

        Register a Prediction set corresponding to a specified Model and Dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registry_service_register_prediction_set_with_http_info(body, project_id_uuid, model_id_uuid, dataset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DatasetIdPredictionBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :param str model_id_uuid: Unique object ID. (required)
        :param str dataset_id: Uniquely specifies a Dataset. (required)
        :return: RimeRegisterPredictionSetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id_uuid', 'model_id_uuid', 'dataset_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registry_service_register_prediction_set" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `registry_service_register_prediction_set`")  # noqa: E501
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `registry_service_register_prediction_set`")  # noqa: E501
        # verify the required parameter 'model_id_uuid' is set
        if ('model_id_uuid' not in params or
                params['model_id_uuid'] is None):
            raise ValueError("Missing the required parameter `model_id_uuid` when calling `registry_service_register_prediction_set`")  # noqa: E501
        # verify the required parameter 'dataset_id' is set
        if ('dataset_id' not in params or
                params['dataset_id'] is None):
            raise ValueError("Missing the required parameter `dataset_id` when calling `registry_service_register_prediction_set`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501
        if 'model_id_uuid' in params:
            path_params['modelId.uuid'] = params['model_id_uuid']  # noqa: E501
        if 'dataset_id' in params:
            path_params['datasetId'] = params['dataset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/registry/{projectId.uuid}/model/{modelId.uuid}/dataset/{datasetId}/prediction', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeRegisterPredictionSetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RuleEvaluationMetadataYaraInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_decisive_match': 'bool',
        'action': 'GenerativefirewallFirewallAction',
        'matched_by_rules': 'list[str]'
    }

    attribute_map = {
        'is_decisive_match': 'isDecisiveMatch',
        'action': 'action',
        'matched_by_rules': 'matchedByRules'
    }

    def __init__(self, is_decisive_match=None, action=None, matched_by_rules=None):  # noqa: E501
        """RuleEvaluationMetadataYaraInfo - a model defined in Swagger"""  # noqa: E501
        self._is_decisive_match = None
        self._action = None
        self._matched_by_rules = None
        self.discriminator = None
        if is_decisive_match is not None:
            self.is_decisive_match = is_decisive_match
        if action is not None:
            self.action = action
        if matched_by_rules is not None:
            self.matched_by_rules = matched_by_rules

    @property
    def is_decisive_match(self):
        """Gets the is_decisive_match of this RuleEvaluationMetadataYaraInfo.  # noqa: E501

        Whether we found a decisive YARA rule match. \"decisive\" means that the YARA result lead to a conclusive block or allow and we returned early in the detection pipeline.  # noqa: E501

        :return: The is_decisive_match of this RuleEvaluationMetadataYaraInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_decisive_match

    @is_decisive_match.setter
    def is_decisive_match(self, is_decisive_match):
        """Sets the is_decisive_match of this RuleEvaluationMetadataYaraInfo.

        Whether we found a decisive YARA rule match. \"decisive\" means that the YARA result lead to a conclusive block or allow and we returned early in the detection pipeline.  # noqa: E501

        :param is_decisive_match: The is_decisive_match of this RuleEvaluationMetadataYaraInfo.  # noqa: E501
        :type: bool
        """

        self._is_decisive_match = is_decisive_match

    @property
    def action(self):
        """Gets the action of this RuleEvaluationMetadataYaraInfo.  # noqa: E501


        :return: The action of this RuleEvaluationMetadataYaraInfo.  # noqa: E501
        :rtype: GenerativefirewallFirewallAction
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this RuleEvaluationMetadataYaraInfo.


        :param action: The action of this RuleEvaluationMetadataYaraInfo.  # noqa: E501
        :type: GenerativefirewallFirewallAction
        """

        self._action = action

    @property
    def matched_by_rules(self):
        """Gets the matched_by_rules of this RuleEvaluationMetadataYaraInfo.  # noqa: E501

        Which rules triggered on the text.  # noqa: E501

        :return: The matched_by_rules of this RuleEvaluationMetadataYaraInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._matched_by_rules

    @matched_by_rules.setter
    def matched_by_rules(self, matched_by_rules):
        """Sets the matched_by_rules of this RuleEvaluationMetadataYaraInfo.

        Which rules triggered on the text.  # noqa: E501

        :param matched_by_rules: The matched_by_rules of this RuleEvaluationMetadataYaraInfo.  # noqa: E501
        :type: list[str]
        """

        self._matched_by_rules = matched_by_rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleEvaluationMetadataYaraInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleEvaluationMetadataYaraInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""Library for converting Swagger objects to Python data types such as dataframes."""
import re
from typing import Any, Dict, List, Union

import numpy as np
import pandas as pd

from rime_sdk.swagger.swagger_client.models import (
    RimeCategoryTestResult,
    TestrunresultTestBatchResult,
    TestrunresultTestCase,
    TestrunresultTestRunDetail,
)
from rime_sdk.swagger.swagger_client.models.detection_detection_event import (
    DetectionDetectionEvent,
)

MODEL_PERF_REGEX = r"^metrics\.model_perf.*(ref_metric|eval_metric)$"

# Map of flattened field paths to their types in the Dataframe.
TEST_RUN_COLUMN_TO_SHOW = {
    # Metadata.
    "test_run_id": "str",
    "name": "str",
    "project_id": "str",
    "model_task": "str",  # OPTIONAL
    # The canonical JSON encoding converts enums to their string representations
    # so we do not need to do manual conversions.
    "testing_type": "str",
    "upload_time": "str",
    # Metrics.
    "metrics.duration_millis": "Int64",
    "metrics.num_inputs": "Int64",
    "metrics.num_failing_inputs": "Int64",
    "metrics.summary_counts.total": "Int64",
    "metrics.summary_counts._pass": "Int64",
    "metrics.summary_counts.warning": "Int64",
    "metrics.summary_counts.fail": "Int64",
    "metrics.summary_counts.skip": "Int64",
    "metrics.severity_counts.num_none_severity": "Int64",
    "metrics.severity_counts.num_low_severity": "Int64",
    "metrics.severity_counts.num_high_severity": "Int64",
}

# List of all the columns to hide for a summary test DF.
SUMMARY_TEST_KEYS_TO_HIDE = [
    "category_metrics",
    "description",
    "duration",
    "suggestion",
]

# List of all the columns to hide for a test batch DF.
TEST_BATCH_KEYS_TO_HIDE = [
    "show_in_test_comparisons",
    "failing_rows_result",
    "display",
]

# List of all the columns to hide for a Test Case DF.
TEST_CASE_KEYS_TO_HIDE = [
    "display",
    "url_safe_feature_id",
    "test_case_id",
]

# TestBatchResult columns that need to be converted from string to int64
INT_TEST_BATCH_ATTRIBUTES = [
    "duration_in_millis",
    "summary_counts.total",
    "summary_counts.warning",
    "summary_counts._pass",
    "summary_counts.fail",
    "summary_counts.skip",
]

# Separator to use when flattening JSON into a dataframe.
# columns_to_keep definition relies on this separator.
DF_FLATTEN_SEPARATOR = "."

DATA_OPTIONS = [
    "float_value",
    "int_value",
    "str_value",
    "float_list",
    "int_list",
    "str_list",
]

EVENT_COLUMNS_TO_SHOW = [
    "project_id",
    "event_type",
    "severity",
    "event_object_name",
    "event_object_id",
    "risk_category_type",
    "test_category",
    "event_time_range.start_time",
    "event_time_range.end_time",
    "description",
    "detail.metric_degradation.rca_result.description",
]


def _flatten_uuid_field_name(field_name: str) -> str:
    """Flatten a UUID field name."""
    match = re.match(r"(.*)\.uuid$", field_name)
    if match is None:
        return field_name
    return match.groups()[0]


def parse_test_run_metadata(test_run: TestrunresultTestRunDetail) -> pd.DataFrame:
    """Parse test run metadata Swagger message into a Pandas dataframe.

    The columns are not guaranteed to be returned in sorted order.
    Some values are optional and will appear as a NaN value in the dataframe.

    """
    # Use the canonical JSON encoding for Protobuf messages.
    test_run_dict = test_run.to_dict()

    # Flatten out nested fields in the Protobuf message.
    # The DF column name will be the field path joined by the `df_flatten_separator.`
    normalized_df = pd.json_normalize(test_run_dict, sep=DF_FLATTEN_SEPARATOR)
    normalized_df = normalized_df.rename(_flatten_uuid_field_name, axis="columns")

    default_test_run_columns = list(TEST_RUN_COLUMN_TO_SHOW.keys())

    # Include the model perf columns with the set of DF columns.
    # These are metrics like "Accuracy" over the reference and eval datasets.
    model_perf_columns = [c for c in normalized_df if re.match(MODEL_PERF_REGEX, c)]
    all_test_run_columns = default_test_run_columns + model_perf_columns

    missing_columns = set(all_test_run_columns).difference(set(normalized_df.columns))
    intersect_df = normalized_df[
        normalized_df.columns.intersection(all_test_run_columns)
    ]

    # Fill in the missing columns with None values.
    kwargs: Dict[str, None] = {}
    for column in missing_columns:
        kwargs[column] = None
    # Note that this step does not preserve column order.
    full_df = intersect_df.assign(**kwargs)

    # The canonical Protobuf<>JSON encoding converts int64 values to string,
    # so we need to convert them back.
    # https://developers.google.com/protocol-buffers/docs/proto3#json
    # Note the type of all model perf metrics should be float64 so we do not have
    # to do this conversion.
    for key, value in TEST_RUN_COLUMN_TO_SHOW.items():
        if value == "Int64":
            # Some nested fields such as `metrics.severity_counts.low` will be `None`
            # because MessageToDict does not populate nested primitive fields with
            # default values.
            # Since some columns may be `None`, we must convert to `float` first.
            # https://stackoverflow.com/questions/60024262/error-converting-object-string-to-int32-typeerror-object-cannot-be-converted
            full_df[key] = full_df[key].astype("float").astype("Int64")

    # Fix an order for the index of the df.
    non_default_cols = list(
        set(all_test_run_columns).difference(set(default_test_run_columns))
    )
    ordered_index = pd.Index(default_test_run_columns + sorted(non_default_cols))
    return full_df.reindex(ordered_index, axis=1)


def parse_test_batch_result(
    raw_result: TestrunresultTestBatchResult,
    unpack_metrics: bool = False,
) -> pd.Series:
    """Parse test batch result into a series."""
    result_dict = raw_result.to_dict()
    del result_dict["metrics"]
    if unpack_metrics:
        _add_metric_cols(result_dict, raw_result)

    # Note: some keys may be missing for nested singular messages, so we do
    # a safe delete here.
    for key in TEST_BATCH_KEYS_TO_HIDE:
        result_dict.pop(key, None)

    df = pd.json_normalize(result_dict, sep=DF_FLATTEN_SEPARATOR)

    for key in INT_TEST_BATCH_ATTRIBUTES:
        # Some nested fields such as `metrics.severity_counts.low` will be `None`
        # because MessageToDict does not populate nested primitive fields with
        # default values.
        # Since some columns may be `None`, we must convert to `float` first.
        # https://stackoverflow.com/questions/60024262/error-converting-object-string-to-int32-typeerror-object-cannot-be-converted
        df[key] = df[key].astype("float").astype("Int64")

    return df.squeeze(axis=0)


def parse_test_case_result(
    raw_result: TestrunresultTestCase, unpack_metrics: bool = False
) -> dict:
    """Parse swagger Test Case result to pythonic form."""
    result_dict = raw_result.to_dict()
    del result_dict["metrics"]
    if unpack_metrics:
        _add_metric_cols(result_dict, raw_result)

    # Drop the keys to hide if they are specified.
    # Note: some keys may be missing for nested singular messages, so we do
    # a safe delete here.
    for key in TEST_CASE_KEYS_TO_HIDE:
        result_dict.pop(key, None)

    return result_dict


def _add_metric_cols(
    result_dict: dict,
    raw_result: Union[TestrunresultTestCase, TestrunresultTestBatchResult],
) -> None:
    """Unpack test metrics into separate fields."""
    if raw_result.metrics:
        for metric in raw_result.metrics:
            category_string = metric.category
            if category_string:
                prefix = "TEST_METRIC_CATEGORY_"
                category_string = category_string[len(prefix) :]
                metric_value: Any = np.nan
                if metric.empty:
                    pass
                else:
                    for data_option in DATA_OPTIONS:
                        getter = getattr(metric, data_option)
                        if getter is not None:
                            metric_value = getter
                            break
                result_dict[f"{category_string}:{metric.metric}"] = metric_value


def parse_category_test_results(
    raw_result: RimeCategoryTestResult,
    unpack_metrics: bool = False,
) -> dict:
    """Parse swagger summary test result to pythonic form."""
    raw_dict = raw_result.to_dict()
    for key in SUMMARY_TEST_KEYS_TO_HIDE:
        raw_dict.pop(key, None)
    if unpack_metrics:
        for metric in raw_result.category_metrics:
            raw_dict[metric.name] = metric.value
    severity_count_dict = raw_dict.pop("severity_counts")
    for key in severity_count_dict:
        raw_dict[key] = int(severity_count_dict[key])
    return raw_dict


def parse_events_to_df(
    events: List[DetectionDetectionEvent],
) -> pd.DataFrame:
    """Parse a list of Detection Events to a pandas DateFrame."""
    event_dicts = [event.to_dict() for event in events]
    df = pd.json_normalize(event_dicts, sep=DF_FLATTEN_SEPARATOR)
    df = df.rename(_flatten_uuid_field_name, axis="columns")

    intersect_df = df[df.columns.intersection(EVENT_COLUMNS_TO_SHOW)]
    intersect_df = intersect_df.rename({"event_object_id": "monitor_id"}, axis=1)

    return intersect_df



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeCreateNotificationRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'object_type': 'NotificationObjectType',
        'object_id': 'str',
        'emails': 'list[str]',
        'config': 'SchemanotificationConfig',
        'webhooks': 'list[NotificationWebhookConfig]'
    }

    attribute_map = {
        'object_type': 'objectType',
        'object_id': 'objectId',
        'emails': 'emails',
        'config': 'config',
        'webhooks': 'webhooks'
    }

    def __init__(self, object_type=None, object_id=None, emails=None, config=None, webhooks=None):  # noqa: E501
        """RimeCreateNotificationRequest - a model defined in Swagger"""  # noqa: E501
        self._object_type = None
        self._object_id = None
        self._emails = None
        self._config = None
        self._webhooks = None
        self.discriminator = None
        if object_type is not None:
            self.object_type = object_type
        self.object_id = object_id
        if emails is not None:
            self.emails = emails
        if config is not None:
            self.config = config
        if webhooks is not None:
            self.webhooks = webhooks

    @property
    def object_type(self):
        """Gets the object_type of this RimeCreateNotificationRequest.  # noqa: E501


        :return: The object_type of this RimeCreateNotificationRequest.  # noqa: E501
        :rtype: NotificationObjectType
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """Sets the object_type of this RimeCreateNotificationRequest.


        :param object_type: The object_type of this RimeCreateNotificationRequest.  # noqa: E501
        :type: NotificationObjectType
        """

        self._object_type = object_type

    @property
    def object_id(self):
        """Gets the object_id of this RimeCreateNotificationRequest.  # noqa: E501

        Uniquely specifies an object for the notification. This varies depending on the object type; for Projects, this should be the unique identifier of the project.  # noqa: E501

        :return: The object_id of this RimeCreateNotificationRequest.  # noqa: E501
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this RimeCreateNotificationRequest.

        Uniquely specifies an object for the notification. This varies depending on the object type; for Projects, this should be the unique identifier of the project.  # noqa: E501

        :param object_id: The object_id of this RimeCreateNotificationRequest.  # noqa: E501
        :type: str
        """
        if object_id is None:
            raise ValueError("Invalid value for `object_id`, must not be `None`")  # noqa: E501

        self._object_id = object_id

    @property
    def emails(self):
        """Gets the emails of this RimeCreateNotificationRequest.  # noqa: E501

        List of emails that notifications should be sent to - this can be empty.  # noqa: E501

        :return: The emails of this RimeCreateNotificationRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._emails

    @emails.setter
    def emails(self, emails):
        """Sets the emails of this RimeCreateNotificationRequest.

        List of emails that notifications should be sent to - this can be empty.  # noqa: E501

        :param emails: The emails of this RimeCreateNotificationRequest.  # noqa: E501
        :type: list[str]
        """

        self._emails = emails

    @property
    def config(self):
        """Gets the config of this RimeCreateNotificationRequest.  # noqa: E501


        :return: The config of this RimeCreateNotificationRequest.  # noqa: E501
        :rtype: SchemanotificationConfig
        """
        return self._config

    @config.setter
    def config(self, config):
        """Sets the config of this RimeCreateNotificationRequest.


        :param config: The config of this RimeCreateNotificationRequest.  # noqa: E501
        :type: SchemanotificationConfig
        """

        self._config = config

    @property
    def webhooks(self):
        """Gets the webhooks of this RimeCreateNotificationRequest.  # noqa: E501

        List of webhooks that notifications should be sent to - this can be empty.  # noqa: E501

        :return: The webhooks of this RimeCreateNotificationRequest.  # noqa: E501
        :rtype: list[NotificationWebhookConfig]
        """
        return self._webhooks

    @webhooks.setter
    def webhooks(self, webhooks):
        """Sets the webhooks of this RimeCreateNotificationRequest.

        List of webhooks that notifications should be sent to - this can be empty.  # noqa: E501

        :param webhooks: The webhooks of this RimeCreateNotificationRequest.  # noqa: E501
        :type: list[NotificationWebhookConfig]
        """

        self._webhooks = webhooks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeCreateNotificationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeCreateNotificationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeAgent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'agent_id': 'RimeUUID',
        'name': 'str',
        'creation_time': 'datetime',
        'status': 'RimeAgentStatus',
        'internal': 'bool',
        'last_heartbeat_time': 'datetime',
        'version': 'str',
        'desired_state': 'RimeAgentDesiredState',
        'type': 'RimeAgentType',
        'url': 'str'
    }

    attribute_map = {
        'agent_id': 'agentId',
        'name': 'name',
        'creation_time': 'creationTime',
        'status': 'status',
        'internal': 'internal',
        'last_heartbeat_time': 'lastHeartbeatTime',
        'version': 'version',
        'desired_state': 'desiredState',
        'type': 'type',
        'url': 'url'
    }

    def __init__(self, agent_id=None, name=None, creation_time=None, status=None, internal=None, last_heartbeat_time=None, version=None, desired_state=None, type=None, url=None):  # noqa: E501
        """RimeAgent - a model defined in Swagger"""  # noqa: E501
        self._agent_id = None
        self._name = None
        self._creation_time = None
        self._status = None
        self._internal = None
        self._last_heartbeat_time = None
        self._version = None
        self._desired_state = None
        self._type = None
        self._url = None
        self.discriminator = None
        if agent_id is not None:
            self.agent_id = agent_id
        if name is not None:
            self.name = name
        if creation_time is not None:
            self.creation_time = creation_time
        if status is not None:
            self.status = status
        if internal is not None:
            self.internal = internal
        if last_heartbeat_time is not None:
            self.last_heartbeat_time = last_heartbeat_time
        if version is not None:
            self.version = version
        if desired_state is not None:
            self.desired_state = desired_state
        if type is not None:
            self.type = type
        if url is not None:
            self.url = url

    @property
    def agent_id(self):
        """Gets the agent_id of this RimeAgent.  # noqa: E501


        :return: The agent_id of this RimeAgent.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """Sets the agent_id of this RimeAgent.


        :param agent_id: The agent_id of this RimeAgent.  # noqa: E501
        :type: RimeUUID
        """

        self._agent_id = agent_id

    @property
    def name(self):
        """Gets the name of this RimeAgent.  # noqa: E501

        The user specified name of the agent.  # noqa: E501

        :return: The name of this RimeAgent.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RimeAgent.

        The user specified name of the agent.  # noqa: E501

        :param name: The name of this RimeAgent.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def creation_time(self):
        """Gets the creation_time of this RimeAgent.  # noqa: E501

        The time of creation of the agent.  # noqa: E501

        :return: The creation_time of this RimeAgent.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this RimeAgent.

        The time of creation of the agent.  # noqa: E501

        :param creation_time: The creation_time of this RimeAgent.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def status(self):
        """Gets the status of this RimeAgent.  # noqa: E501


        :return: The status of this RimeAgent.  # noqa: E501
        :rtype: RimeAgentStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this RimeAgent.


        :param status: The status of this RimeAgent.  # noqa: E501
        :type: RimeAgentStatus
        """

        self._status = status

    @property
    def internal(self):
        """Gets the internal of this RimeAgent.  # noqa: E501

        Specifies whether the agent is an internal agent. Internal agents come bundled with the deployment.  # noqa: E501

        :return: The internal of this RimeAgent.  # noqa: E501
        :rtype: bool
        """
        return self._internal

    @internal.setter
    def internal(self, internal):
        """Sets the internal of this RimeAgent.

        Specifies whether the agent is an internal agent. Internal agents come bundled with the deployment.  # noqa: E501

        :param internal: The internal of this RimeAgent.  # noqa: E501
        :type: bool
        """

        self._internal = internal

    @property
    def last_heartbeat_time(self):
        """Gets the last_heartbeat_time of this RimeAgent.  # noqa: E501

        The time of the last heartbeat.  # noqa: E501

        :return: The last_heartbeat_time of this RimeAgent.  # noqa: E501
        :rtype: datetime
        """
        return self._last_heartbeat_time

    @last_heartbeat_time.setter
    def last_heartbeat_time(self, last_heartbeat_time):
        """Sets the last_heartbeat_time of this RimeAgent.

        The time of the last heartbeat.  # noqa: E501

        :param last_heartbeat_time: The last_heartbeat_time of this RimeAgent.  # noqa: E501
        :type: datetime
        """

        self._last_heartbeat_time = last_heartbeat_time

    @property
    def version(self):
        """Gets the version of this RimeAgent.  # noqa: E501

        Agent version.  # noqa: E501

        :return: The version of this RimeAgent.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this RimeAgent.

        Agent version.  # noqa: E501

        :param version: The version of this RimeAgent.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def desired_state(self):
        """Gets the desired_state of this RimeAgent.  # noqa: E501


        :return: The desired_state of this RimeAgent.  # noqa: E501
        :rtype: RimeAgentDesiredState
        """
        return self._desired_state

    @desired_state.setter
    def desired_state(self, desired_state):
        """Sets the desired_state of this RimeAgent.


        :param desired_state: The desired_state of this RimeAgent.  # noqa: E501
        :type: RimeAgentDesiredState
        """

        self._desired_state = desired_state

    @property
    def type(self):
        """Gets the type of this RimeAgent.  # noqa: E501


        :return: The type of this RimeAgent.  # noqa: E501
        :rtype: RimeAgentType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RimeAgent.


        :param type: The type of this RimeAgent.  # noqa: E501
        :type: RimeAgentType
        """

        self._type = type

    @property
    def url(self):
        """Gets the url of this RimeAgent.  # noqa: E501

        The url of the agent. E.g., https://dev.my-firewall.rbst.io This is used for firewall agents, which can have a different URL than the control plane.  # noqa: E501

        :return: The url of this RimeAgent.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this RimeAgent.

        The url of the agent. E.g., https://dev.my-firewall.rbst.io This is used for firewall agents, which can have a different URL than the control plane.  # noqa: E501

        :param url: The url of this RimeAgent.  # noqa: E501
        :type: str
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeAgent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeAgent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class DetectionApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def detection_list_detection_events(self, project_id_uuid, **kwargs):  # noqa: E501
        """ListDetectionEvents  # noqa: E501

        List out events for a given project. Detection events represent problems Robust Intelligence detects in different risk categories, such as performance degradation or security risk. This is a paginated method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.detection_list_detection_events(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :param str first_page_req_event_object_id: Optional: return a series of detection events for a single object.
        :param datetime first_page_req_event_time_range_start_time:
        :param datetime first_page_req_event_time_range_end_time:
        :param str first_page_req_severity: Optional: When unspecified, returns all.   - SEVERITY_UNSPECIFIED: Indicates that no test runs for the specified metric.  - SEVERITY_PASS: Indicates that the specified metric is lower than the low threshold in the case where the Monitor is configured to trigger on an increase of a metric.  - SEVERITY_WARNING: Indicates that the specified metric is higher than the low threshold but still lower than the high threshold, in the case that a Monitor is configured to trigger on an increase of a metric. Warning and Alert severity levels will trigger a Degradation event.  - SEVERITY_ALERT: Indicates that the specified metric is higher than the high threshold in the case that the Monitor is configured to trigger on an increase of a metric. Warning and Alert severity level will trigger a Degradation event.
        :param list[str] first_page_req_event_types: Optional: When the list is empty, returns all.
        :param list[str] first_page_req_risk_category_types: Optional: When the list is empty, returns all.
        :param list[str] first_page_req_test_categories: Optional: When the list is empty, return all.
        :param str first_page_req_sort_sort_order:
        :param str first_page_req_sort_sort_by:
        :param bool first_page_req_include_resolved:
        :param str page_token: Specifies a page of the list returned by a ListDetectionEvents query. The ListDetectionEvents query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageReq field.
        :param str page_size: The maximum number of Detection Event objects to return in a single page.
        :return: RimeListDetectionEventsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.detection_list_detection_events_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.detection_list_detection_events_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
            return data

    def detection_list_detection_events_with_http_info(self, project_id_uuid, **kwargs):  # noqa: E501
        """ListDetectionEvents  # noqa: E501

        List out events for a given project. Detection events represent problems Robust Intelligence detects in different risk categories, such as performance degradation or security risk. This is a paginated method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.detection_list_detection_events_with_http_info(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :param str first_page_req_event_object_id: Optional: return a series of detection events for a single object.
        :param datetime first_page_req_event_time_range_start_time:
        :param datetime first_page_req_event_time_range_end_time:
        :param str first_page_req_severity: Optional: When unspecified, returns all.   - SEVERITY_UNSPECIFIED: Indicates that no test runs for the specified metric.  - SEVERITY_PASS: Indicates that the specified metric is lower than the low threshold in the case where the Monitor is configured to trigger on an increase of a metric.  - SEVERITY_WARNING: Indicates that the specified metric is higher than the low threshold but still lower than the high threshold, in the case that a Monitor is configured to trigger on an increase of a metric. Warning and Alert severity levels will trigger a Degradation event.  - SEVERITY_ALERT: Indicates that the specified metric is higher than the high threshold in the case that the Monitor is configured to trigger on an increase of a metric. Warning and Alert severity level will trigger a Degradation event.
        :param list[str] first_page_req_event_types: Optional: When the list is empty, returns all.
        :param list[str] first_page_req_risk_category_types: Optional: When the list is empty, returns all.
        :param list[str] first_page_req_test_categories: Optional: When the list is empty, return all.
        :param str first_page_req_sort_sort_order:
        :param str first_page_req_sort_sort_by:
        :param bool first_page_req_include_resolved:
        :param str page_token: Specifies a page of the list returned by a ListDetectionEvents query. The ListDetectionEvents query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageReq field.
        :param str page_size: The maximum number of Detection Event objects to return in a single page.
        :return: RimeListDetectionEventsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id_uuid', 'first_page_req_event_object_id', 'first_page_req_event_time_range_start_time', 'first_page_req_event_time_range_end_time', 'first_page_req_severity', 'first_page_req_event_types', 'first_page_req_risk_category_types', 'first_page_req_test_categories', 'first_page_req_sort_sort_order', 'first_page_req_sort_sort_by', 'first_page_req_include_resolved', 'page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method detection_list_detection_events" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `detection_list_detection_events`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501

        query_params = []
        if 'first_page_req_event_object_id' in params:
            query_params.append(('firstPageReq.eventObjectId', params['first_page_req_event_object_id']))  # noqa: E501
        if 'first_page_req_event_time_range_start_time' in params:
            query_params.append(('firstPageReq.eventTimeRange.startTime', params['first_page_req_event_time_range_start_time']))  # noqa: E501
        if 'first_page_req_event_time_range_end_time' in params:
            query_params.append(('firstPageReq.eventTimeRange.endTime', params['first_page_req_event_time_range_end_time']))  # noqa: E501
        if 'first_page_req_severity' in params:
            query_params.append(('firstPageReq.severity', params['first_page_req_severity']))  # noqa: E501
        if 'first_page_req_event_types' in params:
            query_params.append(('firstPageReq.eventTypes', params['first_page_req_event_types']))  # noqa: E501
            collection_formats['firstPageReq.eventTypes'] = 'multi'  # noqa: E501
        if 'first_page_req_risk_category_types' in params:
            query_params.append(('firstPageReq.riskCategoryTypes', params['first_page_req_risk_category_types']))  # noqa: E501
            collection_formats['firstPageReq.riskCategoryTypes'] = 'multi'  # noqa: E501
        if 'first_page_req_test_categories' in params:
            query_params.append(('firstPageReq.testCategories', params['first_page_req_test_categories']))  # noqa: E501
            collection_formats['firstPageReq.testCategories'] = 'multi'  # noqa: E501
        if 'first_page_req_sort_sort_order' in params:
            query_params.append(('firstPageReq.sort.sortOrder', params['first_page_req_sort_sort_order']))  # noqa: E501
        if 'first_page_req_sort_sort_by' in params:
            query_params.append(('firstPageReq.sort.sortBy', params['first_page_req_sort_sort_by']))  # noqa: E501
        if 'first_page_req_include_resolved' in params:
            query_params.append(('firstPageReq.includeResolved', params['first_page_req_include_resolved']))  # noqa: E501
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/detection-events/{projectId.uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListDetectionEventsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RegistryHuggingFaceDataInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dataset_uri': 'str',
        'split_name': 'str',
        'loading_params_json': 'str'
    }

    attribute_map = {
        'dataset_uri': 'datasetUri',
        'split_name': 'splitName',
        'loading_params_json': 'loadingParamsJson'
    }

    def __init__(self, dataset_uri=None, split_name=None, loading_params_json=None):  # noqa: E501
        """RegistryHuggingFaceDataInfo - a model defined in Swagger"""  # noqa: E501
        self._dataset_uri = None
        self._split_name = None
        self._loading_params_json = None
        self.discriminator = None
        self.dataset_uri = dataset_uri
        self.split_name = split_name
        if loading_params_json is not None:
            self.loading_params_json = loading_params_json

    @property
    def dataset_uri(self):
        """Gets the dataset_uri of this RegistryHuggingFaceDataInfo.  # noqa: E501

        The unique identifier of the dataset.  # noqa: E501

        :return: The dataset_uri of this RegistryHuggingFaceDataInfo.  # noqa: E501
        :rtype: str
        """
        return self._dataset_uri

    @dataset_uri.setter
    def dataset_uri(self, dataset_uri):
        """Sets the dataset_uri of this RegistryHuggingFaceDataInfo.

        The unique identifier of the dataset.  # noqa: E501

        :param dataset_uri: The dataset_uri of this RegistryHuggingFaceDataInfo.  # noqa: E501
        :type: str
        """
        if dataset_uri is None:
            raise ValueError("Invalid value for `dataset_uri`, must not be `None`")  # noqa: E501

        self._dataset_uri = dataset_uri

    @property
    def split_name(self):
        """Gets the split_name of this RegistryHuggingFaceDataInfo.  # noqa: E501

        The string that represents the name of a predefined subset of data.  # noqa: E501

        :return: The split_name of this RegistryHuggingFaceDataInfo.  # noqa: E501
        :rtype: str
        """
        return self._split_name

    @split_name.setter
    def split_name(self, split_name):
        """Sets the split_name of this RegistryHuggingFaceDataInfo.

        The string that represents the name of a predefined subset of data.  # noqa: E501

        :param split_name: The split_name of this RegistryHuggingFaceDataInfo.  # noqa: E501
        :type: str
        """
        if split_name is None:
            raise ValueError("Invalid value for `split_name`, must not be `None`")  # noqa: E501

        self._split_name = split_name

    @property
    def loading_params_json(self):
        """Gets the loading_params_json of this RegistryHuggingFaceDataInfo.  # noqa: E501

        This is a JSON-serialized string from a map.  # noqa: E501

        :return: The loading_params_json of this RegistryHuggingFaceDataInfo.  # noqa: E501
        :rtype: str
        """
        return self._loading_params_json

    @loading_params_json.setter
    def loading_params_json(self, loading_params_json):
        """Sets the loading_params_json of this RegistryHuggingFaceDataInfo.

        This is a JSON-serialized string from a map.  # noqa: E501

        :param loading_params_json: The loading_params_json of this RegistryHuggingFaceDataInfo.  # noqa: E501
        :type: str
        """

        self._loading_params_json = loading_params_json

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RegistryHuggingFaceDataInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RegistryHuggingFaceDataInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ContinuoustestsFirewallIdUuidBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'firewall_id': 'object',
        'test_run_incremental_config': 'TestrunTestRunIncrementalConfig',
        'override_existing_bins': 'bool',
        'agent_id': 'RimeUUID',
        'internal_created': 'bool',
        'experimental_fields': 'dict(str, object)'
    }

    attribute_map = {
        'firewall_id': 'firewallId',
        'test_run_incremental_config': 'testRunIncrementalConfig',
        'override_existing_bins': 'overrideExistingBins',
        'agent_id': 'agentId',
        'internal_created': 'internalCreated',
        'experimental_fields': 'experimentalFields'
    }

    def __init__(self, firewall_id=None, test_run_incremental_config=None, override_existing_bins=None, agent_id=None, internal_created=None, experimental_fields=None):  # noqa: E501
        """ContinuoustestsFirewallIdUuidBody - a model defined in Swagger"""  # noqa: E501
        self._firewall_id = None
        self._test_run_incremental_config = None
        self._override_existing_bins = None
        self._agent_id = None
        self._internal_created = None
        self._experimental_fields = None
        self.discriminator = None
        if firewall_id is not None:
            self.firewall_id = firewall_id
        if test_run_incremental_config is not None:
            self.test_run_incremental_config = test_run_incremental_config
        if override_existing_bins is not None:
            self.override_existing_bins = override_existing_bins
        if agent_id is not None:
            self.agent_id = agent_id
        if internal_created is not None:
            self.internal_created = internal_created
        if experimental_fields is not None:
            self.experimental_fields = experimental_fields

    @property
    def firewall_id(self):
        """Gets the firewall_id of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501

        Uniquely specifies a Firewall.  # noqa: E501

        :return: The firewall_id of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501
        :rtype: object
        """
        return self._firewall_id

    @firewall_id.setter
    def firewall_id(self, firewall_id):
        """Sets the firewall_id of this ContinuoustestsFirewallIdUuidBody.

        Uniquely specifies a Firewall.  # noqa: E501

        :param firewall_id: The firewall_id of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501
        :type: object
        """

        self._firewall_id = firewall_id

    @property
    def test_run_incremental_config(self):
        """Gets the test_run_incremental_config of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501


        :return: The test_run_incremental_config of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501
        :rtype: TestrunTestRunIncrementalConfig
        """
        return self._test_run_incremental_config

    @test_run_incremental_config.setter
    def test_run_incremental_config(self, test_run_incremental_config):
        """Sets the test_run_incremental_config of this ContinuoustestsFirewallIdUuidBody.


        :param test_run_incremental_config: The test_run_incremental_config of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501
        :type: TestrunTestRunIncrementalConfig
        """

        self._test_run_incremental_config = test_run_incremental_config

    @property
    def override_existing_bins(self):
        """Gets the override_existing_bins of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501


        :return: The override_existing_bins of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501
        :rtype: bool
        """
        return self._override_existing_bins

    @override_existing_bins.setter
    def override_existing_bins(self, override_existing_bins):
        """Sets the override_existing_bins of this ContinuoustestsFirewallIdUuidBody.


        :param override_existing_bins: The override_existing_bins of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501
        :type: bool
        """

        self._override_existing_bins = override_existing_bins

    @property
    def agent_id(self):
        """Gets the agent_id of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501


        :return: The agent_id of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """Sets the agent_id of this ContinuoustestsFirewallIdUuidBody.


        :param agent_id: The agent_id of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501
        :type: RimeUUID
        """

        self._agent_id = agent_id

    @property
    def internal_created(self):
        """Gets the internal_created of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501

        This is set in the BE for jobs created by an internal worker.  # noqa: E501

        :return: The internal_created of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501
        :rtype: bool
        """
        return self._internal_created

    @internal_created.setter
    def internal_created(self, internal_created):
        """Sets the internal_created of this ContinuoustestsFirewallIdUuidBody.

        This is set in the BE for jobs created by an internal worker.  # noqa: E501

        :param internal_created: The internal_created of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501
        :type: bool
        """

        self._internal_created = internal_created

    @property
    def experimental_fields(self):
        """Gets the experimental_fields of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501

        Fields that enable experimental functionality.  WARNING: these fields are experimental; ie, their functionality may not be reliable or backwards-compatible. Do not use these fields in production.  # noqa: E501

        :return: The experimental_fields of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._experimental_fields

    @experimental_fields.setter
    def experimental_fields(self, experimental_fields):
        """Sets the experimental_fields of this ContinuoustestsFirewallIdUuidBody.

        Fields that enable experimental functionality.  WARNING: these fields are experimental; ie, their functionality may not be reliable or backwards-compatible. Do not use these fields in production.  # noqa: E501

        :param experimental_fields: The experimental_fields of this ContinuoustestsFirewallIdUuidBody.  # noqa: E501
        :type: dict(str, object)
        """

        self._experimental_fields = experimental_fields

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ContinuoustestsFirewallIdUuidBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContinuoustestsFirewallIdUuidBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeTestMetric(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'metric': 'str',
        'category': 'RimeTestMetricCategory',
        'int_value': 'str',
        'float_value': 'float',
        'empty': 'object',
        'str_value': 'str',
        'int_list': 'RimeIntList',
        'float_list': 'RimeFloatList',
        'str_list': 'RimeStrList',
        'test_case_monitor_info': 'RimeTestCaseMonitorInfo'
    }

    attribute_map = {
        'metric': 'metric',
        'category': 'category',
        'int_value': 'intValue',
        'float_value': 'floatValue',
        'empty': 'empty',
        'str_value': 'strValue',
        'int_list': 'intList',
        'float_list': 'floatList',
        'str_list': 'strList',
        'test_case_monitor_info': 'testCaseMonitorInfo'
    }

    def __init__(self, metric=None, category=None, int_value=None, float_value=None, empty=None, str_value=None, int_list=None, float_list=None, str_list=None, test_case_monitor_info=None):  # noqa: E501
        """RimeTestMetric - a model defined in Swagger"""  # noqa: E501
        self._metric = None
        self._category = None
        self._int_value = None
        self._float_value = None
        self._empty = None
        self._str_value = None
        self._int_list = None
        self._float_list = None
        self._str_list = None
        self._test_case_monitor_info = None
        self.discriminator = None
        if metric is not None:
            self.metric = metric
        if category is not None:
            self.category = category
        if int_value is not None:
            self.int_value = int_value
        if float_value is not None:
            self.float_value = float_value
        if empty is not None:
            self.empty = empty
        if str_value is not None:
            self.str_value = str_value
        if int_list is not None:
            self.int_list = int_list
        if float_list is not None:
            self.float_list = float_list
        if str_list is not None:
            self.str_list = str_list
        if test_case_monitor_info is not None:
            self.test_case_monitor_info = test_case_monitor_info

    @property
    def metric(self):
        """Gets the metric of this RimeTestMetric.  # noqa: E501


        :return: The metric of this RimeTestMetric.  # noqa: E501
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """Sets the metric of this RimeTestMetric.


        :param metric: The metric of this RimeTestMetric.  # noqa: E501
        :type: str
        """

        self._metric = metric

    @property
    def category(self):
        """Gets the category of this RimeTestMetric.  # noqa: E501


        :return: The category of this RimeTestMetric.  # noqa: E501
        :rtype: RimeTestMetricCategory
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this RimeTestMetric.


        :param category: The category of this RimeTestMetric.  # noqa: E501
        :type: RimeTestMetricCategory
        """

        self._category = category

    @property
    def int_value(self):
        """Gets the int_value of this RimeTestMetric.  # noqa: E501


        :return: The int_value of this RimeTestMetric.  # noqa: E501
        :rtype: str
        """
        return self._int_value

    @int_value.setter
    def int_value(self, int_value):
        """Sets the int_value of this RimeTestMetric.


        :param int_value: The int_value of this RimeTestMetric.  # noqa: E501
        :type: str
        """

        self._int_value = int_value

    @property
    def float_value(self):
        """Gets the float_value of this RimeTestMetric.  # noqa: E501


        :return: The float_value of this RimeTestMetric.  # noqa: E501
        :rtype: float
        """
        return self._float_value

    @float_value.setter
    def float_value(self, float_value):
        """Sets the float_value of this RimeTestMetric.


        :param float_value: The float_value of this RimeTestMetric.  # noqa: E501
        :type: float
        """

        self._float_value = float_value

    @property
    def empty(self):
        """Gets the empty of this RimeTestMetric.  # noqa: E501


        :return: The empty of this RimeTestMetric.  # noqa: E501
        :rtype: object
        """
        return self._empty

    @empty.setter
    def empty(self, empty):
        """Sets the empty of this RimeTestMetric.


        :param empty: The empty of this RimeTestMetric.  # noqa: E501
        :type: object
        """

        self._empty = empty

    @property
    def str_value(self):
        """Gets the str_value of this RimeTestMetric.  # noqa: E501


        :return: The str_value of this RimeTestMetric.  # noqa: E501
        :rtype: str
        """
        return self._str_value

    @str_value.setter
    def str_value(self, str_value):
        """Sets the str_value of this RimeTestMetric.


        :param str_value: The str_value of this RimeTestMetric.  # noqa: E501
        :type: str
        """

        self._str_value = str_value

    @property
    def int_list(self):
        """Gets the int_list of this RimeTestMetric.  # noqa: E501


        :return: The int_list of this RimeTestMetric.  # noqa: E501
        :rtype: RimeIntList
        """
        return self._int_list

    @int_list.setter
    def int_list(self, int_list):
        """Sets the int_list of this RimeTestMetric.


        :param int_list: The int_list of this RimeTestMetric.  # noqa: E501
        :type: RimeIntList
        """

        self._int_list = int_list

    @property
    def float_list(self):
        """Gets the float_list of this RimeTestMetric.  # noqa: E501


        :return: The float_list of this RimeTestMetric.  # noqa: E501
        :rtype: RimeFloatList
        """
        return self._float_list

    @float_list.setter
    def float_list(self, float_list):
        """Sets the float_list of this RimeTestMetric.


        :param float_list: The float_list of this RimeTestMetric.  # noqa: E501
        :type: RimeFloatList
        """

        self._float_list = float_list

    @property
    def str_list(self):
        """Gets the str_list of this RimeTestMetric.  # noqa: E501


        :return: The str_list of this RimeTestMetric.  # noqa: E501
        :rtype: RimeStrList
        """
        return self._str_list

    @str_list.setter
    def str_list(self, str_list):
        """Sets the str_list of this RimeTestMetric.


        :param str_list: The str_list of this RimeTestMetric.  # noqa: E501
        :type: RimeStrList
        """

        self._str_list = str_list

    @property
    def test_case_monitor_info(self):
        """Gets the test_case_monitor_info of this RimeTestMetric.  # noqa: E501


        :return: The test_case_monitor_info of this RimeTestMetric.  # noqa: E501
        :rtype: RimeTestCaseMonitorInfo
        """
        return self._test_case_monitor_info

    @test_case_monitor_info.setter
    def test_case_monitor_info(self, test_case_monitor_info):
        """Sets the test_case_monitor_info of this RimeTestMetric.


        :param test_case_monitor_info: The test_case_monitor_info of this RimeTestMetric.  # noqa: E501
        :type: RimeTestCaseMonitorInfo
        """

        self._test_case_monitor_info = test_case_monitor_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeTestMetric, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeTestMetric):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
